==> git-pm-1.0.0.tar.gz: git-pm-1.0.0/git_pm/core.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-

__version__ = '1.0.0'
__version_name__ = 'Apollinaire'

__poetry__ = '''
            I still desire you, o paradise lost
            All our deep kisses I look back on them
            The wind blows soft as a bitten kiss
            After memories memories again.
            ---
            Je te désire encore ô paradis perdu
            Tous nos profonds baisers je me les remémore
            Il fait un vent tout doux comme un baiser mordu
            Après des souvenirs des souvenirs encore.
            '''

##imports
#stdlib
import sys
import getpass
#self
from lib.text import red, bold
from lib.parser import parse, confparse
from lib.tools import Logger
import lib.operations


def run(args=sys.argv[1:]):
    """
    runs the git package manager
    output will be logged to the log folder defined in config.ini
    (default = /var/log/git-pm) except if the git package manager
    is called with commands info or flush.
    """
    try:
        options = parse(args)
        if options['log']['alwayslog'] and options['cmd'] not in ('info', 'flush', 'list'):
            sys.stdout = Logger(filepath = options['log']['path'], err=False, quiet=options['quiet'])
            sys.stderr = Logger(filepath = options['log']['path'], err=True,  quiet=options['quiet'])
        operation = getattr(lib.operations, options['cmd'])
        operation(options)
    except SystemExit:
        pass
    except KeyboardInterrupt:
        print(bold(red('\rgit-pm was stopped')))

if __name__=="__main__":
    run()

==> git-pm-1.1.16.tar.gz: git-pm-1.1.16/git_pm/core.py <==
#!/usr/bin/python3
# -*- coding: utf-8 -*-

__version__ = '1.1.16'
__version_name__ = 'Aragon'

__poetry__ = '''
            My pretty love my dear love my tearing
            I bear you inside me like an injuried bird
            and those ones look at us passing without knowing
            Repeating after me the words I had wreathed
            and which for your great eyes died right away
            \tThere is no happy love
            '''

##imports
#stdlib
import sys
import getpass
#self
from lib.text import red, bold
from lib.parser import parse, confparse
from lib.tools import Logger
import lib.operations


def run(args=sys.argv[1:]):
    """
    runs the git package manager
    output will be logged to the log folder defined in config.ini
    (default = /var/log/git-pm) except if the git package manager
    is called with commands info or flush.
    """
    try:
        options = parse(args)
        #enable logging depending on operation (won't log when you try to delete logs, duh!)
        if options['log']['alwayslog'] and options['cmd'] not in ('info', 'flush', 'list'):
            sys.stdout = Logger(filepath = options['log']['path'], err=False, quiet=options['quiet'])
            sys.stderr = Logger(filepath = options['log']['path'], err=True,  quiet=options['quiet'])
        #run the command passed in args
        operation = getattr(lib.operations, options['cmd'])
        operation(options)
    except KeyboardInterrupt:# properly stops the program
        print(bold(red('\rgit-pm was stopped')))

if __name__=="__main__":
    run()
